@@ -26,7 +26,6 @@
 #include <CalendarErrors.h>
 #include "cal-home-calendar-util.h"
 
-
 static time_t 
 cal_home_advance_date_by_time_period(struct tm* start,
 				     const CalTimePeriod& ctp)
@@ -252,14 +251,17 @@ cal_delete_ccomponentset_items(SortedCComponentSet& ccomponent_set)
 }
 
 static gboolean 
-cal_date_on_today(const time_t& t,
+cal_date_on_today(CComponent* component,
 		  CalHomePlugin* desktop_plugin)
 {
-  struct tm* time = localtime(&t);
+  //  struct tm* time = localtime(&t);
+  struct tm time;
+  time_t t = component->getDateStart();
+  time_get_remote(t, component->getTzid().c_str(), &time);
 
-  return time->tm_year == desktop_plugin->date_today.tm_year &&
-    time->tm_mon == desktop_plugin->date_today.tm_mon &&
-    time->tm_mday== desktop_plugin->date_today.tm_mday;
+  return time.tm_year == desktop_plugin->date_today.tm_year &&
+    time.tm_mon == desktop_plugin->date_today.tm_mon &&
+    time.tm_mday== desktop_plugin->date_today.tm_mday;
 }
 
 static void
@@ -297,7 +299,7 @@ static void
 _format_todo_time(CComponent* component, gchar* buf, CalHomePlugin* desktop_plugin)
 {
   time_t start_time = component->getDateStart();
-  if(cal_date_on_today(start_time, desktop_plugin))
+  if(cal_date_on_today(component, desktop_plugin))
   {
     desktop_plugin->today_events++;
     sprintf(buf,"%s", dgettext("calendar", "cal_va_allday_home"));
@@ -344,6 +346,7 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
     gtk_list_store_append(list_store,
 			  &iter);
     string summary = (*event_iter)->getSummary();
+
     if((*event_iter)->getType() == E_TODO &&
        (*event_iter)->getStatus() == 1)
     {
@@ -372,7 +375,7 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
     time_t event_start_time = (*event_iter)->getDateStart();
     time_t event_end_time = (*event_iter)->getDateEnd();
     time_t event_time_offset = (*event_iter)->getTzOffset();
-
+    /*
     if(CMulticalendar::MCInstance()->getSystemTimeShift() != (*event_iter)->getTzOffset() &&
        ((*event_iter)->getAllDay() ||
 	(*event_iter)->getType() == E_TODO))
@@ -380,7 +383,7 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
       event_end_time += event_time_offset - system_time_offset;
       event_start_time += event_time_offset - system_time_offset;
     }
-
+    */
 
 
     if(event_end_time > date_today_time && earliest_update_end_time>event_end_time)
@@ -393,7 +396,9 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
       earliest_update_end_time = event_start_time+60;
     }
     char buf[255];
-    struct tm* time = localtime(&event_start_time);
+    //    struct tm* time = localtime(&event_start_time);
+    struct tm time;
+    time_get_remote(event_start_time, (*event_iter)->getTzid().c_str(), &time);
 
     if((*event_iter)->getType() == E_TODO)
     {
@@ -402,21 +407,21 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
 			 0, buf,
 			 -1);
     }
-    else if(cal_date_on_today(event_start_time, desktop_plugin) || 
+    else if(cal_date_on_today((*event_iter), desktop_plugin) || 
 	    (event_start_time <= date_today_time && (event_end_time == -1 || event_end_time >= date_today_time)))
     {
       ++desktop_plugin->today_events;
 
-      if((*event_iter)->getAllDay() || (event_start_time <= date_today_time && 
-					end_time >= end_time_today))
-      {      
-	gtk_list_store_set(list_store, &iter,
-			   0, dgettext("calendar", "cal_va_allday_home"),
-			   -1);
+      if(((*event_iter)->getAllDay() || (event_start_time <= date_today_time && 
+						  end_time >= end_time_today)))
+	{      
+	  gtk_list_store_set(list_store, &iter,
+			     0, dgettext("calendar", "cal_va_allday_home"),
+			     -1);
       }
       else
       {
-	_format_time(buf, time, desktop_plugin->has_24_time_format);
+	_format_time(buf, &time, desktop_plugin->has_24_time_format);
 	gtk_list_store_set(list_store, &iter,
 			   0, buf,
 			   -1);
@@ -427,12 +432,12 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
       if(desktop_plugin->show_week_day_name)
       {
 	gchar* tt = g_strdup_printf("%s", dgettext("hildon-libs","wdgt_va_date_day_name_short"));
-	strftime(buf, 255, tt, time);
+	strftime(buf, 255, tt, &time);
 	g_free(tt);
       }
       else
-	//	strftime(buf, 255,dgettext("hildon-libs","wdgt_va_date_short"), time);
-	strftime(buf, 255,dgettext("hildon-libs","wdgt_va_date"), time);
+	strftime(buf, 255,dgettext("hildon-libs","wdgt_va_date_short"), &time);
+      //strftime(buf, 255,dgettext("hildon-libs","wdgt_va_date"), &time);
       gtk_list_store_set(list_store, &iter,
 			 0, buf,
 			 -1);
@@ -758,6 +763,7 @@ cal_read_ccomponents_for_calendar(CCalendar* calendar,
 	}
 	else
 	{
+	  time_t system_time_offset = CMulticalendar::MCInstance()->getSystemTimeShift();
 	  vector<time_t>::const_iterator iter = instance_times.begin();
 	  do
 	  {
@@ -765,7 +771,7 @@ cal_read_ccomponents_for_calendar(CCalendar* calendar,
 	    // and set end time 
 	    CComponent* c = new CComponent(*component);
 	    c->setDateEnd((*iter) + c->getDateEnd() - c->getDateStart());
-	    c->setDateStart((*iter) + c->getTzOffset());
+	    c->setDateStart((*iter));
 
 	    if(c->getType() == E_BDAY &&
 	       desktop_plugin->show_age)
